<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:output method="html" encoding="utf-8" indent="yes"/>
	<xsl:include href="main.xsl"/>
	<xsl:include href="default.xsl"/>
	<xsl:include href="administration-menu.xsl"/>
	
	<xsl:template match="configuration">
		<h1>System Settings</h1>
		
		<table>
			<tr>
				<th>Key</th>
				<th style="width: 15em;">Value</th>
			</tr>
			<tr>
				<td>autoConfig</td>
				<td><xsl:value-of select="@autoConfig"/></td>
			</tr>
	
			<xsl:for-each select="*">
				<xsl:for-each select="@*">
					<tr>
						<td><xsl:value-of select="name(..)"/> -- <xsl:value-of select="name()"/></td>
						<td><xsl:value-of select="./."/></td>
					</tr>
				</xsl:for-each>
			</xsl:for-each>
		</table>
	
	</xsl:template>
	
	<xsl:template match="autoConfig-form">
		<h1>Configuration Mode Settings</h1>
		<form method="post" action="autoConfig.html">
			  
			<table>
				<tr>
					<td class="form">Centralized Configuration Enabled:</td>
					<td>
						<input type='hidden' name='autoConfig'/>
						<input type="checkbox" name="autoConfig">
							<xsl:if test="autoConfig/@value='true'">
								<xsl:attribute name="checked"><xsl:text>checked</xsl:text></xsl:attribute>
							</xsl:if>
						</input>
					</td>
				</tr>
			</table>
			
			<div id="submit">
				<input type="submit" value="Save"/>
			</div>
		</form>
		
	</xsl:template>
	
	<xsl:template match="network-form">
	
		<h1>Network Settings</h1>
		
		<xsl:if test="autoConfig/@value='true'">
			<p id="warning">Warning: Centralized configuration is enabled. It must be disabled first to change these settings.</p>
		</xsl:if>
		
		<form method="post" action="/service/config/network.html">
			<table>
				<tr>
					<td class="form">Hostname:</td>
					<td>
						<input name="hostname" type="text">
							<xsl:attribute name="value"><xsl:value-of select="hostname/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="hostname/@message!=''">
						<td><xsl:value-of select="hostname/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">DHCP:</td>
					<td>
						<input type='hidden' name='dhcp'/>
						<input type="checkbox" name="dhcp" id="dhcp" onclick="updateEnabledFields();">
							<xsl:if test="dhcp/@value='true'"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="dhcp/@message!=''">
						<td><xsl:value-of select="dhcp/@message" /></td>
					</xsl:if>
				</tr>
			
				<tr>
					<td class="form">IP Address:</td>
					<td>
						<input name="address" id="address" type="text">
							<xsl:attribute name="value"><xsl:value-of select="address/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="address/@message!=''">
						<td><xsl:value-of select="address/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Subnet Mask:</td>
					<td>
						<input name="netmask" id="netmask" type="text">
							<xsl:attribute name="value"><xsl:value-of select="netmask/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="netmask/@message!=''">
						<td><xsl:value-of select="netmask/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Default Gateway:</td>
					<td>
						<input name="gateway" id="gateway" type="text">
							<xsl:attribute name="value"><xsl:value-of select="gateway/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="gateway/@message!=''">
						<td><xsl:value-of select="gateway/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Nameserver 1:</td>
					<td>
						<input name="nameserver1" id="nameserver1" type="text">
							<xsl:attribute name="value"><xsl:value-of select="nameserver1/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="nameserver1/@message!=''">
						<td><xsl:value-of select="nameserver1/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Nameserver 2:</td>
					<td>
						<input name="nameserver2" id="nameserver2" type="text">
							<xsl:attribute name="value"><xsl:value-of select="nameserver2/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="nameserver2/@message!=''">
						<td><xsl:value-of select="nameserver2/@message" /></td>
					</xsl:if>
				</tr>
			</table>
			
			<xsl:if test="autoConfig/@value!='true'">
				<div id="submit">
					<input type="submit" value="Save"/>
				</div>
			</xsl:if>
		</form>
		
		<script type="text/javascript">
			function updateEnabledFields() {
				var fields = document.getElementsByName('dhcp');
					var enabled = true;
					
					for (var j = 0; j &lt; fields.length; j++) {
						var field = fields[j];
						
						if (field.getAttribute('type') === 'checkbox') {
							enabled = field.checked;
						}
					}
					
				if (enabled) {
					document.getElementById('address').disabled = true;
					document.getElementById('netmask').disabled = true;
					document.getElementById('gateway').disabled = true;
					document.getElementById('nameserver1').disabled = true;
					document.getElementById('nameserver2').disabled = true;			
				}
				else {
					document.getElementById('address').disabled = false;
					document.getElementById('netmask').disabled = false;
					document.getElementById('gateway').disabled = false;
					document.getElementById('nameserver1').disabled = false;
					document.getElementById('nameserver2').disabled = false;				
				}	
			}
			
			window.onload = updateEnabledFields();
		</script>
	</xsl:template>
	
	<xsl:template match="msp-form">
		<h1>MSP Integration Settings</h1>
		
		<xsl:if test="autoConfig/@value='true'">
			<p id="warning">Warning: Centralized configuration is enabled. It must be disabled first to change these settings.</p>
		</xsl:if>
		
		<form method="post" action="/service/config/msp.html">
			<table>
				<tr>
					<td class="form">Enabled:</td>
					<td>
						<input type='hidden' name='enabled'/>
						<input type="checkbox" name="enabled">
							<xsl:if test="enabled/@value='true'"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="enabled/@message!=''">
						<td><xsl:value-of select="enabled/@message" /></td>
					</xsl:if>
				</tr>
			
				<tr>
					<td class="form">Relay Host:</td>
					<td>
						<input name="relayHostname" type="text">
							<xsl:attribute name="value"><xsl:value-of select="relayHostname/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="relayHostname/@message!=''">
						<td><xsl:value-of select="relayHostname/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Relay Port:</td>
					<td>
						<input type="text" name="port">
							<xsl:attribute name="value"><xsl:value-of select="port/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="port/@message!=''">
						<td><xsl:value-of select="port/@message" /></td>
					</xsl:if>
				</tr>
			
				<tr>
					<td class="form">Username:</td>
					<td>
						<input name="username" type="text">
							<xsl:attribute name="value"><xsl:value-of select="username/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="username/@message!=''">
						<td><xsl:value-of select="username/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Password:</td>
					<td>
						<input name="password" type="password">
							<xsl:attribute name="value"><xsl:value-of select="password/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="password/@message!=''">
						<td><xsl:value-of select="password/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Upload Interval [Minutes]:</td>
					<td>
						<input name="uploadInterval" type="text">
							<xsl:attribute name="value"><xsl:value-of select="uploadInterval/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="uploadInterval/@message!=''">
						<td><xsl:value-of select="uploadInterval/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Discovery Path:</td>
					<td>
						<input name="path" type="text">
							<xsl:attribute name="value"><xsl:value-of select="path/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="path/@message!=''">
						<td><xsl:value-of select="path/@message" /></td>
					</xsl:if>
				</tr>
			</table>
			
			<xsl:if test="autoConfig/@value!='true'">
				<div id="submit">
					<input type="submit" value="Save"/>
				</div>
			</xsl:if>
		</form>
		
		</xsl:template>
			
	<xsl:template match="datetime-form">
		<script type="text/javascript">
			function updateEnabledFields() {
				if (document.getElementById('enabled').checked) {
					document.getElementById('day').disabled = true;
					document.getElementById('month').disabled = true;
					document.getElementById('year').disabled = true;
					document.getElementById('hours').disabled = true;
					document.getElementById('minutes').disabled = true;
					
					document.getElementsByName('timeServerWarning')[0].style.display = "block";
				}
				else {
					document.getElementById('day').disabled = false;
					document.getElementById('month').disabled = false;
					document.getElementById('year').disabled = false;
					document.getElementById('hours').disabled = false;
					document.getElementById('minutes').disabled = false;
					
					document.getElementsByName('timeServerWarning')[0].style.display = "none";
				}	
			}
		</script>
		<h1>Time Server and Timezone Settings</h1>
		
		<xsl:if test="autoConfig/@value='true'">
			<p id="warning">Warning: Centralized configuration is enabled. It must be disabled first to change these settings.</p>
		</xsl:if>
		
		<h2>Time Server Settings</h2>
		
		<form method="post" action="/service/config/datetime.html">
			<table>
				<tr>
					<td class="form">Enabled:</td>
					<td>
						<input type='hidden' name='enabled'/>
						<input type="checkbox" name="enabled" id="enabled" onclick="updateEnabledFields();">
							<xsl:if test="enabled/@value='true'"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="enabled/@message!=''">
						<td><xsl:value-of select="enabled/@message" /></td>
					</xsl:if>
				</tr>
			
				<tr>
					<td class="form">NTP Server:</td>
					<td>
						<input name="timeServer" type="text">
							<xsl:attribute name="value"><xsl:value-of select="timeServer/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="timeServer/@message!=''">
						<td><xsl:value-of select="timeServer/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Update Interval [Minutes]:</td>
					<td>
						<input type="text" name="updateInterval">
							<xsl:attribute name="value"><xsl:value-of select="updateInterval/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="updateInterval/@message!=''">
						<td><xsl:value-of select="updateInterval/@message" /></td>
					</xsl:if>
				</tr>
			</table>
			<h2>Time zone</h2>
			<table>
				<tr>
					<td class="form">Time zone:</td>
					<td>
						<select id="ap_timezone" name="timeZone">
							<xsl:if test="autoConfig/@value = 'true'">
								<xsl:attribute name="disabled">true</xsl:attribute>
							</xsl:if>
							<xsl:for-each select="timeZones/timeZone">
							<xsl:sort select="@rawOffset" data-type="number"/>
							
								<option>
									<xsl:if test="@value = ../../timeZone/@value">
										<xsl:attribute name="selected">true</xsl:attribute>
									</xsl:if>
									<xsl:attribute name="name"><xsl:value-of select="@offset"/>;<xsl:value-of select="@dst"/></xsl:attribute>
									<xsl:value-of select="@value"/>
								</option>
							</xsl:for-each>
						</select>
					</td>
				</tr>				
			</table>
			
			<!--<xsl:if test="autoConfig/@value!='true'">
				<div id="submit">
					<input type="submit" value="Save"/>
				</div>
			</xsl:if>
		-->
			

			
			<h1>Manual Date/Time Settings <span><a href="/service/config/datetime.xml">(Refresh)</a></span></h1>
			
			<p id="warning" name="timeServerWarning">
				<xsl:if test="enabled/@value='false'">
					<xsl:attribute name="style">display:none</xsl:attribute>
				</xsl:if>
				Warning: Time server is enabled. In order to manually update date/time settings, disable time server first.
			</p>
			
			<h2>Date</h2>

			<table>
				<tr>
					<td class="form">Day:</td>
					<td>
						<select id="day" name="day">
							<xsl:if test="autoConfig/@value='true'">
								<xsl:attribute name="disabled">
									true
								</xsl:attribute>
							</xsl:if>
							
							<xsl:call-template name="repeatable">
								<xsl:with-param name="index" select="1"/>
								<xsl:with-param name="total" select="31"/>
								<xsl:with-param name="current" select="day/@value"/>
							</xsl:call-template>
						</select>
					</td>
					<td class="form">Month:</td>
					<td>
						<select id="month" name="month">
							<xsl:if test="autoConfig/@value='true'">
								<xsl:attribute name="disabled">
									true
								</xsl:attribute>
							</xsl:if>
							
							<xsl:call-template name="repeatable">
								<xsl:with-param name="index" select="1"/>
								<xsl:with-param name="total" select="12"/>
								<xsl:with-param name="current" select="month/@value"/>
							</xsl:call-template>						
						</select>
					</td>
					<td class="form">Year:</td>
					<td>
						<select id="year" name="year">
							<xsl:if test="autoConfig/@value='true'">
								<xsl:attribute name="disabled">
									true
								</xsl:attribute>
							</xsl:if>
							
							<xsl:call-template name="repeatable">
								<xsl:with-param name="index" select="year/@value - 40"/>
								<xsl:with-param name="total" select="year/@value + 40"/>
								<xsl:with-param name="current" select="year/@value"/>
							</xsl:call-template>						
						</select>
					</td>
					
					<xsl:if test="day/@message!=''">
						<td><xsl:value-of select="day/@message" /></td>
					</xsl:if>

				</tr>
			</table>
			<h2>Time</h2>
			<table>	
				<tr>
					<td class="form">Hours:</td>
					<td>
						<select id="hours" name="hours">
							<xsl:if test="autoConfig/@value='true'">
								<xsl:attribute name="disabled">
									true
								</xsl:attribute>
							</xsl:if>
							
							<xsl:call-template name="repeatable">
								<xsl:with-param name="index" select="1"/>
								<xsl:with-param name="total" select="31"/>
								<xsl:with-param name="current" select="hours/@value"/>
							</xsl:call-template>
						</select>
					</td>
					<td class="form">Minutes:</td>
					<td>
						<select id="minutes" name="minutes">
							<xsl:if test="autoConfig/@value='true'">
								<xsl:attribute name="disabled">
									true
								</xsl:attribute>
							</xsl:if>
							
							<xsl:call-template name="repeatable">
								<xsl:with-param name="index" select="0"/>
								<xsl:with-param name="total" select="59"/>
								<xsl:with-param name="current" select="minutes/@value"/>
							</xsl:call-template>
						</select>
					</td>					
				</tr>
			</table>
			<h2>Local Date/Time</h2>
			<table>
				<tr>
					<td class="form">Date:</td>
					<td id="localDate"></td>
				</tr>
				<tr>
					<td class="form">Time:</td>
					<td id="localTime"></td>
				</tr>
			</table>
			
			<script type="text/javascript">
				function onWindowLoad() {
					updateEnabledFields();
					var currentDate = new Date();
					var day = currentDate.getDate();
				
					if (10 > day) {
						day = "0" + day;
					}
					
					var month = currentDate.getMonth() + 1;
					
					if (10 > month) {
						month = "0" + month;
					}
					
					var year = currentDate.getFullYear();
					var hours = currentDate.getHours();
					
					if (10 > hours) {
						hours = "0" + hours;
					}
					
					var minutes = currentDate.getMinutes();
					
					if (10 > minutes) {
						minutes = "0" + minutes;
					}
					
					document.getElementById('localDate').textContent = day + "." + month + "." + year;
					document.getElementById('localTime').textContent = hours + ":" + minutes;
				}
			
				window.onload = onWindowLoad();

			</script>
			
			<xsl:if test="autoConfig/@value!='true'">
				<div id="submit">
					<input type="submit" value="Save">
						<xsl:if test="autoConfig/@value='true'">
							<xsl:attribute name="disabled">
								true
							</xsl:attribute>
						</xsl:if>					
					</input>
				</div>
			</xsl:if>
			<br/>
			
				<input type="hidden" name="fixedDateTime"><xsl:attribute name="value"><xsl:value-of select="fixedDateTime/@value" /></xsl:attribute></input>
			
		</form>
	</xsl:template>
	
	<xsl:template name="repeatable">
		<xsl:param name="index"/>
		<xsl:param name="total"/>
		<xsl:param name="current"/>
			<option>
				<xsl:attribute name="name"><xsl:value-of select="$index"/></xsl:attribute>
				
				<xsl:if test="$current = $index">
					<xsl:attribute name="selected">true</xsl:attribute>
				</xsl:if>
				
				<xsl:choose>
					<xsl:when test="string-length($index) = 1">
						<xsl:attribute name="value">0<xsl:value-of select="$index"/></xsl:attribute>
						0<xsl:value-of select="$index"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="value"><xsl:value-of select="$index"/></xsl:attribute>
						<xsl:value-of select="$index"/>
					</xsl:otherwise>
				</xsl:choose>
				
			</option>

		<xsl:if test="not($index = $total)">
			<xsl:call-template name="repeatable">
				<xsl:with-param name="index" select="$index + 1" />
				<xsl:with-param name="total" select="$total" />
				<xsl:with-param name="current" select="$current" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="broadcast-form">
		<h1>Discovery Broadcast Settings</h1>
		
		<xsl:if test="autoConfig/@value='true'">
			<p id="warning">Warning: Centralized configuration is enabled. It must be disabled first to change these settings.</p>
		</xsl:if>
		
		<form method="post" action="/service/config/broadcast.html">
			<table>
				<tr>
					<td class="form">Enabled:</td>
					<td>
						<input type='hidden' name='enabled'/>
						<input type="checkbox" name="enabled">
							<xsl:if test="enabled/@value='true'">
								<xsl:attribute name="checked">checked</xsl:attribute>
								<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
							</xsl:if>
						</input>
					</td>
					<xsl:if test="enabled/@message!=''">
						<td><xsl:value-of select="enabled/@message" /></td>
					</xsl:if>
				</tr>
			
				<tr>
					<td class="form">Broadcast Port:</td>
					<td>
						<input name="broadcastPort" type="text">
							<xsl:attribute name="value"><xsl:value-of select="broadcastPort/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="broadcastPort/@message!=''">
						<td><xsl:value-of select="broadcastPort/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Broadcast Interval [Minutes]:</td>
					<td>
						<input type="text" name="broadcastIntervalInMinutes">
							<xsl:attribute name="value"><xsl:value-of select="broadcastIntervalInMinutes/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="broadcastIntervalInMinutes/@message!=''">
						<td><xsl:value-of select="broadcastIntervalInMinutes/@message" /></td>
					</xsl:if>
				</tr>
			</table>
			
			<xsl:if test="autoConfig/@value!='true'">
				<div id="submit">
					<input type="submit" value="Save"/>
				</div>
			</xsl:if>
		</form>
			
	</xsl:template>
	
	<xsl:template match="wireless-form">
		<h1>Wireless Settings</h1>
		
		<xsl:if test="autoConfig/@value='true'">
			<p id="warning">Warning: Centralized configuration is enabled. It must be disabled first to change these settings.</p>
		</xsl:if>
		
		<h2>Wireless Channel Selection</h2>
	
		<form method="post" action="/service/config/wireless.html">
			<table>
				<tr>
					<th colspan="2">Name</th>
					<th>Peak Frequency</th>
				</tr>
			
				<xsl:for-each select="channels/channel">
					<tr>
						<td>
							<xsl:if test="../../wirelessChannel/@value=@id">
								<xsl:attribute name="class">selected</xsl:attribute>
							</xsl:if>
							<input name="wirelessChannel" type="radio">
								<xsl:attribute name="value"><xsl:value-of select="@id"/></xsl:attribute>
								<xsl:if test="../../wirelessChannel/@value=@id"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
								<xsl:if test="../../autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
							</input>
						</td>
						<td class="centered">
							<xsl:if test="../../wirelessChannel/@value=@id"><xsl:attribute name="class">centered selected</xsl:attribute></xsl:if>
							ESL Channel <xsl:value-of select="@caption"/>
						</td>
						<td class="centered">
							<xsl:if test="../../wirelessChannel/@value=@id"><xsl:attribute name="class">centered selected</xsl:attribute></xsl:if>
							<xsl:value-of select="@frequency"/> MHz
						</td>
					</tr>
				</xsl:for-each>
				
				<tr>
					<td>
						<xsl:if test="wirelessChannel/@value=''">
							<xsl:attribute name="class">selected</xsl:attribute>
						</xsl:if>
						<input name="wirelessChannel" type="radio">
							<xsl:attribute name="value"></xsl:attribute>
							<xsl:if test="wirelessChannel/@value=''"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<td class="centered" colspan="2">
						<xsl:if test="wirelessChannel/@value=''"><xsl:attribute name="class">centered selected</xsl:attribute></xsl:if>
						Disable radio interface
					</td>
				</tr>
			</table>
			
			<xsl:if test="autoConfig/@value!='true'">
				<div id="submit">
					<input type="submit" value="Save"/>
				</div>
			</xsl:if>
		</form>
	</xsl:template>
	
	<xsl:template match="rf-power-form">
		<h1>Output Power Settings</h1>
		
		<xsl:if test="autoConfig/@value='true'">
			<p id="warning">Warning: Centralized configuration is enabled. It must be disabled first to change these settings.</p>
		</xsl:if>
		
		<h2>Radio Output Power Selection</h2>
	
		<form method="post" action="/service/config/outputPower.html">
			<table>
				<tr>
					<th colspan="2">Output Power</th>
				</tr>
			
				<xsl:for-each select="rf-settings/rf-setting">
					<tr>
						<td>
							<xsl:if test="../../rfPower/@value=@id">
								<xsl:attribute name="class">selected</xsl:attribute>
							</xsl:if>
							<input name="rfPower" type="radio">
								<xsl:attribute name="value"><xsl:value-of select="@id"/></xsl:attribute>
								<xsl:if test="../../rfPower/@value=@id"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
								<xsl:if test="../../autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
							</input>
						</td>
						<td class="centered">
							<xsl:if test="../../rfPower/@value=@id"><xsl:attribute name="class">centered selected</xsl:attribute></xsl:if>
							<xsl:value-of select="@caption"/>
						</td>
					</tr>
				</xsl:for-each>
			</table>
			
			<xsl:if test="autoConfig/@value!='true'">
				<div id="submit">
					<input type="submit" value="Save"/>
				</div>
			</xsl:if>
		</form>
	</xsl:template>
	
	<xsl:template match="logging-form">
		<h1>Logging Settings</h1>
		
		<xsl:if test="autoConfig/@value='true'">
			<p id="warning">Warning: Centralized configuration is enabled. It must be disabled first to change these settings.</p>
		</xsl:if>
		
		<form method="post" action="/service/config/logging.html">
			<table>
				<tr>
					<td class="form">Logging Level:</td>
					<td>
						<select name="logLevel">
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
							<xsl:for-each select="logLevels/logLevel">
								<option>
									<xsl:if test="@id=../../logLevel/@value"><xsl:attribute name="selected">selected</xsl:attribute></xsl:if>
									<xsl:attribute name="value"><xsl:value-of select="@id"/></xsl:attribute>
									<xsl:value-of select="@caption"/>
								</option>
							</xsl:for-each>
						</select>
					</td>
					<xsl:if test="logLevel/@message!=''">
						<td><xsl:value-of select="logLevel/@message" /></td>
					</xsl:if>
				</tr>
			
				<tr>
					<td class="form">Remote Logging Enabled:</td>
					<td>
						<input type='hidden' name='socketAppenderEnabled'/>
						<input type="checkbox" name="socketAppenderEnabled">
							<xsl:if test="socketAppenderEnabled/@value='true'"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="socketAppenderEnabled/@message!=''">
						<td><xsl:value-of select="socketAppenderEnabled/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Remote Logging Host:</td>
					<td>
						<input name="socketRemoteAddress" type="text">
							<xsl:attribute name="value"><xsl:value-of select="socketRemoteAddress/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="socketRemoteAddress/@message!=''">
						<td><xsl:value-of select="socketRemoteAddress/@message" /></td>
					</xsl:if>
				</tr>
			
				<tr>
					<td class="form">Remote Logging Port:</td>
					<td>
						<input name="socketPort" type="text">
							<xsl:attribute name="value"><xsl:value-of select="socketPort/@value"/></xsl:attribute>
							<xsl:if test="autoConfig/@value='true'"><xsl:attribute name="disabled">disabled</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="socketPort/@message!=''">
						<td><xsl:value-of select="socketPort/@message" /></td>
					</xsl:if>
				</tr>
			</table>
			
			<xsl:if test="autoConfig/@value!='true'">
				<div id="submit">
					<input type="submit" value="Save"/>
				</div>
			</xsl:if>
		</form>
			
	</xsl:template>
	
	<xsl:template match="certificate-signing-request">
		<h1>Certificate Signing Request (CSR)</h1>
		
		<pre>
			<xsl:value-of select="."/>
		</pre>
	</xsl:template>
	
	<xsl:template match="certificate">
		<h1>Certificate</h1>
		
		<h2>Details</h2>
		
		<table>
			<tr>
				<td class="form">Version:</td>
				<td><xsl:value-of select="version"/></td>
			</tr>
			<tr>
				<td class="form">Serial Number:</td>
				<td><xsl:value-of select="serialNumber"/></td>
			</tr>
			<tr>
				<td class="form">Subject DN:</td>
				<td><xsl:value-of select="subjectDN"/></td>
			</tr>
			<tr>
				<td class="form">Issuer DN:</td>
				<td><xsl:value-of select="issuerDN"/></td>
			</tr>
			<tr>
				<td class="form">Valid until:</td>
				<td><xsl:value-of select="notAfter"/></td>
			</tr>
		</table>
		
		<h2>PEM</h2>
		
		<pre>
			<xsl:value-of select="pem"/>
		</pre>
	</xsl:template>

	<xsl:template match="forms">
		<table>
			<tr>
				<th colspan="2">Actions</th>
			</tr>
			<xsl:apply-templates/>
		</table>
	</xsl:template>

	<xsl:template match="changePassword">
	<xsl:apply-templates select="../root"/>
		<h1>Change Password</h1>
		
		<form action="/service/config/password.html" method="POST">
			<table>
				<tr>
					<td class="form">Old Password:</td>
					<td><input type="password" name="oldPassword"/></td>
				</tr>
				<tr>
					<td class="form">New Password:</td>
					<td><input type="password" name="newPassword"/></td>
				</tr>
				<tr>
					<td class="form">Confirm New Password:</td>
					<td><input type="password" name="newPasswordConfirm"/></td>
				</tr>
			</table>
			
			<div id="submit">
				<input type="submit" value="Apply"/>
			</div>
		</form>
	</xsl:template>
	
	<xsl:template match="form">
		<tr>
			<td>
				<xsl:value-of select="@caption"/>
			</td>
			<td>
				<form>
					<xsl:attribute name="id">
						<xsl:value-of select="@name" />
					</xsl:attribute>
				
					<xsl:attribute name="action">
						<xsl:value-of select="@action" />
					</xsl:attribute>
				
					<xsl:attribute name="method">
						<xsl:value-of select="@method" />
					</xsl:attribute>
					
					<xsl:if test="@enctype != ''">
						<xsl:attribute name="enctype">
							<xsl:value-of select="@enctype" />
						</xsl:attribute>	
					</xsl:if>				
					<xsl:apply-templates/> 
				</form>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="confirm-button">
		<input type="button">
			<xsl:attribute name="onClick">
				if(confirm('<xsl:value-of select="@question" />')) document.forms["<xsl:value-of select="../@name" />"].submit(); 
			</xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="@caption"/></xsl:attribute>
		</input>
	</xsl:template>
	
	<xsl:template match="file-upload">
		<script type="text/javascript">
			document.forms["<xsl:value-of select="../@name" />"].enctype = "multipart/form-data";
		</script>
		<input type="file" accept="multipart/form-data">
			<xsl:attribute name="id">
				<xsl:value-of select="@name" />
			</xsl:attribute>
			<xsl:attribute name="name">
				<xsl:value-of select="@name" />
			</xsl:attribute>
		</input>
		
		<input type="button">
			<xsl:attribute name="onClick">
				if(document.getElementById('<xsl:value-of select="@name" />').value == '') {
					alert("Please select a file to upload");
				}
				else {
					if(confirm('<xsl:value-of select="@question" />')) document.forms["<xsl:value-of select="../@name" />"].submit(); 
				}
			</xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="@caption"/></xsl:attribute>
		</input>
	</xsl:template>
	
	<xsl:template match="serial-form">
		<h1>Serial Settings</h1>
		<h2>WiSpy Settings</h2>
	
		<form method="post" action="/service/serial/serialConfiguration.html">
			<table>
				<tr>
					<td class="form">WiSpy enabled:</td>
					<td>
						<input type='hidden' name='wiSpyEnabled'/>
						<input type="checkbox" name="wiSpyEnabled" id="wiSpyEnabled" onclick="updateEnabledFields();">
							<xsl:if test="wiSpyEnabled/@value='true'"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
						</input>
					</td>
					<xsl:if test="wiSpyEnabled/@message!=''">
						<td><xsl:value-of select="wiSpyEnabled/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Start frequency [Hz]:</td>
					<td>
						<input name="startFrequency" id="startFrequency" type="text">
							<xsl:attribute name="value"><xsl:value-of select="startFrequency/@value"/></xsl:attribute>
						</input>
					</td>
					<xsl:if test="startFrequency/@message!=''">
						<td><xsl:value-of select="startFrequency/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">End frequency [Hz]:</td>
					<td>
						<input name="endFrequency" id="endFrequency" type="text">
							<xsl:attribute name="value"><xsl:value-of select="endFrequency/@value"/></xsl:attribute>
						</input>
					</td>
					<xsl:if test="endFrequency/@message!=''">
						<td><xsl:value-of select="endFrequency/@message" /></td>
					</xsl:if>
				</tr>
				
				<tr>
					<td class="form">Number of sweeps:</td>
					<td>
						<input name="numberOfSweeps" id="numberOfSweeps" type="text">
							<xsl:attribute name="value"><xsl:value-of select="numberOfSweeps/@value"/></xsl:attribute>
						</input>
					</td>
					<xsl:if test="numberOfSweeps/@message!=''">
						<td><xsl:value-of select="numberOfSweeps/@message" /></td>
					</xsl:if>
				</tr>
			</table>
			
			<h3>Channel Filter Bandwidths</h3>
			
			<xsl:if test="channelFilterBandwidth/@message!=''">
					<p id="error"><xsl:value-of select="channelFilterBandwidth/@message" /></p>
			</xsl:if>
			
			<table>
				<tr>
					<th colspan="2">Bandwidth</th>
				</tr>
				<xsl:for-each select="ChannelFilterBandwidthList/ChannelFilterBandwidth">
					<tr>
						<td>
							<xsl:if test="../../channelFilterBandwidth/@value=@name">
								<xsl:attribute name="class">selected</xsl:attribute>
							</xsl:if>
							<input name="channelFilterBandwidth" type="radio">
								<xsl:attribute name="value"><xsl:value-of select="@name"/></xsl:attribute>
								<xsl:if test="../../channelFilterBandwidth/@value=@name"><xsl:attribute name="checked">checked</xsl:attribute></xsl:if>
							</input>
						</td>
						<td class="centered">
							<xsl:if test="../../channelFilterBandwidth/@value=@name">
								<xsl:attribute name="class">selected selected</xsl:attribute>
							</xsl:if>
							Bandwidth <xsl:value-of select="@bandwidth"/> kHz
						</td>
					</tr>
				</xsl:for-each>
			</table>
			<script type="text/javascript">
			
				function updateEnabledFields() {
					var fields = document.getElementsByName('wiSpyEnabled');
					var enabled = true;
					
					for (var j = 0; j &lt; fields.length; j++) {
						var field = fields[j];
						
						if (field.getAttribute('type') === 'checkbox') {
							enabled = field.checked;
						}
					}
					
					if (enabled) {
						document.getElementById('startFrequency').removeAttribute('disabled');
						document.getElementById('endFrequency').removeAttribute('disabled');
						document.getElementById('numberOfSweeps').removeAttribute('disabled');
						var elements = document.getElementsByName('channelFilterBandwidth');
						
						for (var i = 0; i &lt; elements.length; i++) {
							elements[i].removeAttribute('disabled');
						}
										
					}
					else {
						document.getElementById('startFrequency').setAttribute('disabled', 'true');
						document.getElementById('endFrequency').setAttribute('disabled', 'true');
						document.getElementById('numberOfSweeps').setAttribute('disabled', 'true');
						var elements = document.getElementsByName('channelFilterBandwidth');
						
						for (var i = 0; i &lt; elements.length; i++) {
							elements[i].setAttribute('disabled', 'true');
						}		
					}	
				}
				
				window.onload = updateEnabledFields();
			</script>
			<div id="submit">
				<input type="submit" value="Save"/>
			</div>
		</form>
	</xsl:template>
	 
	<xsl:template match="header">
		<h1><xsl:value-of select="."/></h1>
	</xsl:template>

</xsl:stylesheet>
