<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">


<!-- Transaction Status -->

<xsl:template match="TransactionStatusInfo">
	<xsl:variable name="progress">
		<xsl:choose>
			<xsl:when test="number(TaskCount) &gt; 0">
				<xsl:value-of select="round((number(FinishedUpdates) div number(TaskCount)) * 100)"/>
			</xsl:when>
			<xsl:otherwise>100</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<h1>Status of Transaction <xsl:value-of select="Id"/></h1>
	
	<h2>Transaction Summary</h2>
	
	<table class="detail">

		<tr>
			<th>Status:</th>
			<xsl:choose>
				<xsl:when test="number(TaskCount) = number(FinishedUpdates) and number(ErrorUpdates) = 0">
					<td class="SUCCESSFUL">All tasks finished successful</td>
				</xsl:when>
				<xsl:when test="number(TaskCount) = number(FinishedUpdates) and number(ErrorUpdates) &gt; 0">
					<td class="ERROR"><xsl:value-of select="ErrorUpdates"/> task(s) failed</td>
				</xsl:when>
				<xsl:otherwise>
					<td class="WAITING">Running</td>
				</xsl:otherwise>
			</xsl:choose>
		</tr>
		
		<tr>
			<th>Progress:</th>
			<td>
				<div style="position: relative; width: 100%; height: 2em; background-color: gray;">
					<div>
						<xsl:attribute name="style">height: 100%; background-color: green; width: <xsl:value-of select="$progress"/>%;</xsl:attribute>
						<div style="position: absolute; top: 4px; left: 0; width: 100%; height: 100%; color: white; font-weight: bold; text-align: center; vertical-align: middle;">
							<xsl:value-of select="$progress"/> %
						</div>
					</div>
				</div>
			</td>
		</tr>
		
		<tr>
			<th>Title:</th>
			<td><xsl:value-of select="Title"/></td>
		</tr>
		
		<tr>
			<th>External ID:</th>
			<td><xsl:value-of select="ExternalId"/></td>
		</tr>
		
		<tr>
			<th>Started at:</th>
			<td><xsl:value-of select="StartedTime"/></td>
		</tr>
		
		<tr>
			<xsl:choose>
				<xsl:when test="number(TaskCount) = number(FinishedUpdates)">
					<th>Finished at:</th>
				</xsl:when>
				<xsl:otherwise>
					<th>Last task update at:</th>
				</xsl:otherwise>
			</xsl:choose>
			<td><xsl:value-of select="LastUpdateTime"/></td>
		</tr>
		
		<tr>
			<th>Task count:</th>
			<td><xsl:value-of select="TaskCount"/></td>
		</tr>
	
		<tr>
			<th>Total tasks:</th>
			<td><xsl:value-of select="TotalUpdates"/></td>
		</tr>

		<tr>
			<th>Finished tasks:</th>
			<td><xsl:value-of select="FinishedUpdates"/></td>
		</tr>
		
		<tr>
			<th>Successful tasks:</th>
			<td><xsl:value-of select="number(FinishedUpdates) - number(ErrorUpdates)"/></td>
		</tr>
		
		<tr>
			<th>Failed tasks:</th>
			<td><xsl:value-of select="ErrorUpdates"/></td>
		</tr>
		
		<tr>
			<th>Waiting tasks:</th>
			<td><xsl:value-of select="number(TaskCount) - number(FinishedUpdates)"/></td>
		</tr>
		
	</table>
	
	<h2>Actions</h2>
	
	<ul>
		<li>
			<a>
				<xsl:attribute name="href">/service/updatestatus/transaction/<xsl:value-of select="Id"/>.xml?page=0</xsl:attribute>
				Show update log
			</a>
		</li>
	</ul>
</xsl:template>


<!-- Query -->

<xsl:template match="QueryList">
	<h1>Query Summary</h1>
	
	<xsl:choose>
		<xsl:when test="@count = 0">
			<p id="message">No records found</p>
		</xsl:when>
		<xsl:otherwise>
			<table class="record">
				<tr>
					<th>URL</th>
					<th>Record Type</th>
					<th>Parameter Type</th>
				</tr>
				
				<xsl:apply-templates select="Query"/>
			</table>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="Query">
	<tr>
		<td>
			<xsl:choose>
				<xsl:when test="ParameterClass = 'Void'">
					<a>
						<xsl:attribute name="href">/service/<xsl:value-of select="Url"/>.xml</xsl:attribute>
						/service/<xsl:value-of select="Url"/>.xml
					</a>
				</xsl:when>
				<xsl:otherwise>
					/service/<xsl:value-of select="Url"/>/&lt;parameter&gt;.xml
				</xsl:otherwise>
			</xsl:choose>
		</td>
		<td>
			<xsl:value-of select="RecordClass"/>
		</td>
		<td>
			<xsl:value-of select="ParameterClass"/>
		</td>
	</tr>
</xsl:template>


<!-- UpdateErrorDescription -->

<xsl:template match="UpdateErrorDescriptionList">
	<h1>Update Errors</h1>
	
	<xsl:choose>
		<xsl:when test="@count = 0">
			<p id="message">No records found</p>
		</xsl:when>
		<xsl:otherwise>
			<table class="record">
				<tr>
					<th>Error Code</th>
					<th>Description</th>
				</tr>
				
				<xsl:apply-templates select="UpdateErrorDescription"/>
			</table>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="UpdateErrorDescriptionEntry">
	<h1>Update Errors</h1>
	
	<xsl:choose>
		<xsl:when test="@count = 0">
			<p id="message">No records found</p>
		</xsl:when>
		<xsl:otherwise>
			<table>
				<tr>
					<th>Error Code</th>
					<th>Description</th>
				</tr>
				
				<xsl:apply-templates select="UpdateErrorDescription"/>
			</table>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="UpdateErrorDescription">
	<tr>
		<td>
			<xsl:value-of select="ErrorCode"/>
		</td>
		<td>
			<xsl:value-of select="Description"/>
		</td>
	</tr>
</xsl:template>


<!-- LabelErrorDescription -->

<xsl:template match="LabelErrorDescriptionList">
	<h1>Label Errors</h1>
	
	<xsl:choose>
		<xsl:when test="@count = 0">
			<p id="message">No records found</p>
		</xsl:when>
		<xsl:otherwise>
			<table>
				<tr>
					<th>Error Code</th>
					<th>Description</th>
				</tr>
				
				<xsl:apply-templates select="LabelErrorDescription"/>
			</table>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="LabelErrorDescription">
	<tr>
		<td>
			<xsl:value-of select="ErrorCode"/>
		</td>
		<td>
			<xsl:value-of select="Description"/>
		</td>
	</tr>
</xsl:template>


<!-- EnumDescriptionList -->

<xsl:template match="EnumDescriptionList">
	<h1><xsl:value-of select="EnumDescription[1]/Type"/></h1>
	
	<table>
		<tr>
			<th>Name</th>
			<th>Description</th>
		</tr>
		
		<xsl:apply-templates select="EnumDescription"/>
	</table>
</xsl:template>

<xsl:template match="EnumDescription">
	<tr>
		<td>
			<xsl:attribute name="class"><xsl:value-of select="Name"/> centered</xsl:attribute>
			<xsl:value-of select="Name"/>
		</td>
		<td>
			<xsl:value-of select="Description"/>
		</td>
	</tr>
</xsl:template>


<!-- LabelTypeDescriptionList -->

<xsl:template match="LabelTypeDescriptionList">
	<h1>Label Types</h1>
	
	<xsl:choose>
		<xsl:when test="@count = 0">
			<p id="message">No records found</p>
		</xsl:when>
		<xsl:otherwise>
			<table>
				<tr>
					<th>Name</th>
					<th>Display</th>
					<th>Colors</th>
					<th>Pages</th>
					<th>Mappings</th>
				</tr>
				
				<xsl:apply-templates select="LabelTypeDescription"/>
			</table>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="LabelTypeDescription">
	<tr>
		<td>
			<xsl:value-of select="Name"/>
		</td>
		<td>
			<xsl:value-of select="DisplayWidth"/> × <xsl:value-of select="DisplayHeight"/>, <xsl:value-of select="DisplayDpi"/> dpi
		</td>
		<td>
			<xsl:value-of select="DisplayColors"/>
		</td>
		<td>
			<xsl:value-of select="AvailablePageCount"/>
		</td>
		<td>
			<xsl:for-each select="Mappings/Item">
				<xsl:value-of select="."/>
				<xsl:if test="position() != last()">, </xsl:if>
			</xsl:for-each>
		</td>
	</tr>
</xsl:template>

</xsl:stylesheet>
